@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use DBD::SQLite 1.27;
+use DBD::SQLite 1.31;
 
 package # hide from PAUSE
     DBIx::DBO::DBD::SQLite;
@@ -21,15 +21,6 @@ sub _get_table_schema {
     return $info->[0][1];
 }
 
-# Hack to fix quoted primary keys
-if (eval "$DBD::SQLite::VERSION < 1.30") {
-    *_set_table_key_info = sub {
-        my($class, $me, $schema, $table, $h) = @_;
-        $class->SUPER::_set_table_key_info($me, $schema, $table, $h);
-        s/^(["'`])(.+)\1$/$2/ for @{$h->{PrimaryKeys}}; # dequote
-    };
-}
-
 sub _save_last_insert_id {
     my($class, $me, $sth) = @_;
     $sth->{Database}->last_insert_id(undef, @$me{qw(Schema Name)}, undef);
